@@ -3,13 +3,13 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 8,
- 'ALIGNOF_SIZE_T': 8,
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wsign-compare -mieee',
+ 'BASECFLAGS': '-Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/pkg/bin',
@@ -22,59 +22,63 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'alpha--netbsd',
+ 'BUILD_GNU_TYPE': 'armv4--netbsdelf-eabi',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -mieee -DNDEBUG -O2 -mieee -I/usr/include '
-           '-I/usr/pkg/include -O2 -mieee -I/usr/include -I/usr/pkg/include '
-           '-O2 -mieee -I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
+           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/include/readline '
+           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/include/readline '
+           '-I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -mieee -I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/include/readline '
+                     '-I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/include/readline '
+                       '-I/usr/pkg/include',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' "
-                "'--with-readline=readline' '--with-system-expat' "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
-                "'--without-pymalloc' '--prefix=/usr/pkg' "
-                "'--build=alpha--netbsd' '--host=alpha--netbsd' "
-                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=alpha--netbsd' 'host_alias=alpha--netbsd' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python311/work.alpha/.tools/bin/pkg-config' "
+                "'--without-pymalloc' '--with-readline=editline' "
+                "'--prefix=/usr/pkg' '--build=armv4--netbsdelf-eabi' "
+                "'--host=armv4--netbsdelf-eabi' '--mandir=/usr/pkg/man' "
+                "'--enable-option-checking=yes' "
+                "'build_alias=armv4--netbsdelf-eabi' "
+                "'host_alias=armv4--netbsdelf-eabi' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python311/work.earmv4/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python311/work.alpha/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python311/work.alpha/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -mieee -I/usr/include "
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python311/work.earmv4/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python311/work.earmv4/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/include/readline "
                 "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
                 '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                 "-Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include "
-                "-I/usr/pkg/include'",
+                "-I/usr/include/readline -I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python311/work.alpha/Python-3.11.8/coverage.info',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python311/work.alpha/Python-3.11.8/lcov-report',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
+             '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
- 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                   '-DHAVE_UINT128_T=1',
+ 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1',
  'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
  'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
@@ -249,7 +253,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 0,
  'HAVE_GDBM_NDBM_H': 0,
@@ -317,7 +321,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
@@ -425,12 +429,12 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RECVFROM': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CATCH_SIGNAL': 1,
- 'HAVE_RL_COMPDISP_FUNC_T': 1,
- 'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
+ 'HAVE_RL_CATCH_SIGNAL': 0,
+ 'HAVE_RL_COMPDISP_FUNC_T': 0,
+ 'HAVE_RL_COMPLETION_APPEND_CHARACTER': 0,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
- 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
+ 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_RPC_RPC_H': 1,
@@ -607,7 +611,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'alpha--netbsd',
+ 'HOST_GNU_TYPE': 'armv4--netbsdelf-eabi',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.11 /usr/pkg/include/python3.11',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -637,30 +641,34 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/pkg/lib/python3.11',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -mieee -DNDEBUG -O2 -mieee -I/usr/include '
-                    '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                    '-I/usr/pkg/include -O2 -mieee -I/usr/include '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-O2 -I/usr/include -I/usr/include/readline '
                     '-I/usr/pkg/include -std=gnu11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                    '-I/usr/pkg/include -fPIC -fPIC',
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBFFI_INCLUDEDIR': '/usr/pkg/include',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -Wsign-compare -mieee -DNDEBUG -O2 '
-                    '-mieee -I/usr/include -I/usr/pkg/include -O2 -mieee '
-                    '-I/usr/include -I/usr/pkg/include -O2 -mieee '
-                    '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
+ 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
+                    '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-O2 -I/usr/include -I/usr/include/readline '
+                    '-I/usr/pkg/include -std=gnu11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                    '-I/usr/pkg/include -fPIC -fPIC',
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -806,8 +814,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CTYPES_TEST_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
-                           '-DANSI=1 -DHAVE_UINT128_T=1',
+ 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
+                           '-DANSI=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
                          'Modules/_decimal/libmpdec/libmpdec.a',
  'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -860,14 +868,14 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                         './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I./Modules/_sqlite',
+ 'MODULE__SQLITE3_CFLAGS': '-I/usr/pkg/include -I./Modules/_sqlite',
  'MODULE__SQLITE3_DEPS': './Modules/_sqlite/connection.h '
                          './Modules/_sqlite/cursor.h '
                          './Modules/_sqlite/microprotocols.h '
                          './Modules/_sqlite/module.h '
                          './Modules/_sqlite/prepare_protocol.h '
                          './Modules/_sqlite/row.h ./Modules/_sqlite/util.h',
- 'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
+ 'MODULE__SQLITE3_LDFLAGS': '-Wl,-R/usr/pkg/lib -L/usr/pkg/lib -lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '-I/usr/include',
@@ -909,7 +917,8 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '-L/usr/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -mieee -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
+        '-I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -945,41 +954,47 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -mieee -DNDEBUG -O2 -mieee '
-                             '-I/usr/include -I/usr/pkg/include -O2 -mieee '
-                             '-I/usr/include -I/usr/pkg/include -O2 -mieee '
-                             '-I/usr/include -I/usr/pkg/include -std=gnu11 '
-                             '-Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                             '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/include/readline '
+                             '-I/usr/pkg/include -O2 -I/usr/include '
+                             '-I/usr/include/readline -I/usr/pkg/include '
+                             '-std=gnu11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/pkg/include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -mieee -DNDEBUG -O2 -mieee -I/usr/include '
-              '-I/usr/pkg/include -O2 -mieee -I/usr/include -I/usr/pkg/include '
-              '-O2 -mieee -I/usr/include -I/usr/pkg/include',
+                             '-I./Include -I/usr/include '
+                             '-I/usr/include/readline -I/usr/pkg/include '
+                             '-I/usr/include -I/usr/include/readline '
+                             '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
+ 'PY_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
+              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
+              '-I/usr/include/readline -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -mieee -DNDEBUG -O2 -mieee -I/usr/include '
-                   '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                   '-I/usr/pkg/include -O2 -mieee -I/usr/include '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                   '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                   '-O2 -I/usr/include -I/usr/include/readline '
                    '-I/usr/pkg/include -std=gnu11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                   '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
+                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                   '-fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-                '-I/usr/include -I/usr/pkg/include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
+                '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
+                '-I/usr/pkg/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
@@ -992,19 +1007,21 @@ build_time_vars = {'ABIFLAGS': '',
                      '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                      '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 0,
- 'PY_SQLITE_HAVE_SERIALIZE': 0,
+ 'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -mieee -DNDEBUG -O2 -mieee '
-                        '-I/usr/include -I/usr/pkg/include -O2 -mieee '
-                        '-I/usr/include -I/usr/pkg/include -O2 -mieee '
-                        '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                        '-I/usr/include -I/usr/include/readline '
+                        '-I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
+                        '-Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/include -I/usr/pkg/include -fPIC',
+                        '-I./Include -I/usr/include -I/usr/include/readline '
+                        '-I/usr/pkg/include -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -fPIC',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1016,7 +1033,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.alpha/Python-3.11.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -1028,18 +1045,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG': 4,
  'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-311',
@@ -1060,10 +1077,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.alpha/Python-3.11.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.alpha/Python-3.11.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1086,7 +1103,7 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
- 'WITH_EDITLINE': 0,
+ 'WITH_EDITLINE': 1,
  'WITH_FREELISTS': 1,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
@@ -1094,8 +1111,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python311/work.alpha/Python-3.11.8',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python311/work.alpha/Python-3.11.8',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python311/work.earmv4/Python-3.11.10',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
